<?php
/**
 * functions.php
 *
 * The theme's functions and definitions.
 */

/**
 * ----------------------------------------------------------------------------------------
 * 1.0 - Define constants.
 * ----------------------------------------------------------------------------------------
 */
define( 'THEMEROOT', get_stylesheet_directory_uri() );
define( 'IMAGES', THEMEROOT . '/images' );
define( 'SCRIPTS', THEMEROOT . '/js' );

require_once( 'wp_bootstrap_navwalker.php' );
/**
 * ----------------------------------------------------------------------------------------
 * 4.0 - Set up theme default and register various supported features.
 * ----------------------------------------------------------------------------------------
 */
if ( ! function_exists( 'alpha_setup' ) ) {
	function alpha_setup() {
		/**
		 * Make the theme available for translation.
		 */
		$lang_dir = THEMEROOT . '/languages';
		load_theme_textdomain( 'alpha', $lang_dir );

		/**
		 * Add support for post formats.
		 */
		add_theme_support( 'post-formats',
			array(
				'gallery',
				'link',
				'image',
				'quote',
				'video',
				'audio'
			)
		);

		/**
		 * Add support for automatic feed links.
		 */
		add_theme_support( 'automatic-feed-links' );

		/**
		 * Add support for post thumbnails.
		 */
		add_theme_support( 'post-thumbnails' );


		/**
		 * Register nav menus.
		 */
		register_nav_menus(
			array(
				'main-menu'    => __( 'القائمة الرئيسية', 'alpha' ),
				'footer1' => __( 'قائمة الفوتر 1', 'alpha' ),
				'footer2' => __( 'قائمة الفوتر 2', 'alpha' )
			)
		);
	}

	add_action( 'after_setup_theme', 'alpha_setup' );
}


/**
 * ----------------------------------------------------------------------------------------
 * 8.0 - Function that validates a field's length.
 * ----------------------------------------------------------------------------------------
 */
if ( ! function_exists( 'alpha_validate_length' ) ) {
	function alpha_validate_length( $fieldValue, $minLength ) {
		// First, remove trailing and leading whitespace
		return ( strlen( trim( $fieldValue ) ) > $minLength );
	}
}


/**
 * ----------------------------------------------------------------------------------------
 * 10.0 - Load the custom scripts for the theme.
 * ----------------------------------------------------------------------------------------
 */
if ( ! function_exists( 'alpha_scripts' ) ) {
	function alpha_scripts() {
		// Adds support for pages with threaded comments
		if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
			wp_enqueue_script( 'comment-reply' );
		}

		// Register scripts
		wp_register_script( 'bootstrap-js', SCRIPTS . '/bootstrap.min.js', array( 'jquery' ), false, true );
		wp_register_script( 'wow-js', SCRIPTS . '/wow.min.js', array( 'jquery' ), false, true );
		wp_register_script( 'mix', 'http://cdn.jsdelivr.net/jquery.mixitup/latest/jquery.mixitup.min.js', array( 'jquery' ), false, true );
		wp_register_script( 'jQuery.scrollSpeed' , SCRIPTS . '/jQuery.scrollSpeed.js', array( 'jquery' ), false, true );
		wp_register_script( 'mix', 'http://cdn.jsdelivr.net/jquery.mixitup/latest/jquery.mixitup.min.js', array( 'jquery' ), false, true );
//		wp_register_script( 'modernizr', SCRIPTS . '/modernizr.custom.97074.js', array( 'jquery' ), false, true );
		wp_register_script( 'owlcarousel', SCRIPTS . '/owl.carousel.min.js', array( 'jquery' ), false, true );
		wp_register_script( 'custom', SCRIPTS . '/custom.js', array( 'jquery' ), false, true );


		// Load the custom scripts
		wp_enqueue_script( 'bootstrap-js' );
		wp_enqueue_script( 'wow-js' );
		wp_enqueue_script( 'mix' );
		wp_enqueue_script( 'jQuery.scrollSpeed' );
		wp_enqueue_script( 'owlcarousel' );
		wp_enqueue_script( 'custom' );
//if(is_rtl()) {
		// Load the stylesheets
		wp_enqueue_style( 'bootstrap', THEMEROOT . '/css/bootstrap.min.css' );
		wp_enqueue_style( 'bootstrap-rtl', THEMEROOT . '/css/bootstrap-rtl.min.css' );
		wp_enqueue_style( 'Fontawesome', THEMEROOT . '/css/font-awesome.min.css' );
		wp_enqueue_style( 'animate', THEMEROOT . '/css/animate.css' );
		wp_enqueue_style( 'owl.carousel', THEMEROOT . '/css/owl.carousel.css' );
		wp_enqueue_style( 'sinister', THEMEROOT . '/css/sinister.css' );
		wp_enqueue_style( 'rtl', THEMEROOT . '/style.css' );

//} else {
//	wp_enqueue_style( 'bootstrap', THEMEROOT . '/css/bootstrap.min.css' );
//	wp_enqueue_style( 'Fontawesome', THEMEROOT . '/css/font-awesome.min.css' );
//	wp_enqueue_style( 'animate', THEMEROOT . '/css/animate.css' );
//	wp_enqueue_style( 'main', THEMEROOT . '/style.css' );
//}

	}

	add_action( 'wp_enqueue_scripts', 'alpha_scripts' );
}


/**
 * ----------------------------------------------------------------------------------------
 * 11.0 - Custom Post Type.
 * ----------------------------------------------------------------------------------------
 */


register_post_type( 'slider', array(
	'public'              => true,
	'hierarchical'        => false,
	'exclude_from_search' => false,
	'has_archive'         => false,
	'rewrite'             => array( 'slug' => 'slider' ),
	'capability_type'     => 'post',
	'taxonomies'          => array( 'post_tag' ),
	'labels'              => array(
		'name'               => 'السلايدر',
		'add_new_item'       => 'إضافة سلايدر',
		'singular_name'      => 'السلايدر',
		'menu_name'          => 'السلايدر',
		'name_admin_bar'     => 'سلايدر',
		'all_items'          => 'كافة السلايدر',
		'add_new'            => 'إضافة سلايدر',
		'edit_item'          => 'تحرير السلايدر',
		'new_item'           => 'سلايدر جديدة',
		'view_item'          => 'مشاهدة السلايدر',
		'search_items'       => 'البحث عن سلايدر',
		'not_found'          => 'لا يوجد سلايدرات.',
		'not_found_in_trash' => 'لا يوجد سلايدرات',
		'parent_item_colon'  => 'القسم الرئيسى'
	),
	'supports'            => array( 'title', 'thumbnail', 'editor' )
) );

register_post_type( 'latest-work', array(
	'public'              => true,
	'hierarchical'        => false,
	'exclude_from_search' => false,
	'has_archive'         => false,
	'rewrite'             => array( 'slug' => 'latest-work' ),
	'capability_type'     => 'post',
	'taxonomies'          => array( 'post_tag' ),
	'labels'              => array(
		'name'               => 'الاعمال',
		'add_new_item'       => 'إضافة عمل',
		'singular_name'      => 'الاعمال',
		'menu_name'          => 'آخر الأعمال',
		'name_admin_bar'     => 'عمل',
		'all_items'          => 'كافة الاعمال',
		'add_new'            => 'إضافة عمل',
		'edit_item'          => 'تحرير الاعمال',
		'new_item'           => 'عمل جديد',
		'view_item'          => 'مشاهدة الاعمال',
		'search_items'       => 'البحث عن عمل',
		'not_found'          => 'لا يوجد اعمال.',
		'not_found_in_trash' => 'لا يوجد اعمال',
		'parent_item_colon'  => 'القسم الرئيسى'
	),
	'supports'            => array( 'title', 'thumbnail', 'editor' )
) );

register_post_type( 'video', array(
	'public'              => true,
	'hierarchical'        => false,
	'exclude_from_search' => false,
	'has_archive'         => false,
	'rewrite'             => array( 'slug' => 'video' ),
	'capability_type'     => 'post',
	'taxonomies'          => array( 'post_tag' ),
	'labels'              => array(
		'name'               => 'الفيديو',
		'add_new_item'       => 'إضافة ',
		'singular_name'      => 'الفيديو',
		'menu_name'          => 'الفيديو',
		'name_admin_bar'     => 'عمل',
		'all_items'          => 'كافة الفيديو',
		'add_new'            => 'إضافة ',
		'edit_item'          => 'تحرير ',
		'new_item'           => ' جديد',
		'view_item'          => 'مشاهدة ',
		'search_items'       => 'البحث ',
		'not_found'          => 'لا يوجد .',
		'not_found_in_trash' => 'لا يوجد ',
		'parent_item_colon'  => 'القسم الرئيسى'
	),
	'supports'            => array( 'title', 'thumbnail', 'editor' )
) );

register_post_type( 'gallery', array(
	'public'              => true,
	'hierarchical'        => false,
	'exclude_from_search' => false,
	'has_archive'         => false,
	'rewrite'             => array( 'slug' => 'gallery' ),
	'capability_type'     => 'post',
	'taxonomies'          => array( 'post_tag' ),
	'labels'              => array(
		'name'               => 'الصور',
		'add_new_item'       => 'إضافة ',
		'singular_name'      => 'الصور',
		'menu_name'          => 'الصور',
		'name_admin_bar'     => 'عمل',
		'all_items'          => 'كافة الصور',
		'add_new'            => 'إضافة ',
		'edit_item'          => 'تحرير ',
		'new_item'           => ' جديد',
		'view_item'          => 'مشاهدة ',
		'search_items'       => 'البحث ',
		'not_found'          => 'لا يوجد .',
		'not_found_in_trash' => 'لا يوجد ',
		'parent_item_colon'  => 'القسم الرئيسى'
	),
	'supports'            => array( 'title', 'thumbnail', 'editor' )
) );
/*************************************************/
/* Tax */
/*************************************************/
add_action( 'init', 'create_latest' );

function create_latest() {
	register_taxonomy(
		'works-sections',
		'latest-work',
		array(
			'label'             => __( 'أقسام الأعمال' ),
			'hierarchical'      => true,
			'show_ui'           => true,
			'show_admin_column' => true,
			'show_in_nav_menus' => true,
			'show_tagcloud'     => true,
			'public'            => true
		)
	);
}

register_post_type( 'services', array(
	'public'              => true,
	'hierarchical'        => false,
	'exclude_from_search' => false,
	'has_archive'         => false,
	'rewrite'             => array( 'slug' => 'services' ),
	'capability_type'     => 'post',
	'taxonomies'          => array( 'post_tag' ),
	'labels'              => array(
		'name'               => 'الخدمات',
		'add_new_item'       => 'إضافة خدمة',
		'singular_name'      => 'الخدمات',
		'menu_name'          => ' خدمات المؤسسة',
		'name_admin_bar'     => 'خدمة',
		'all_items'          => 'كافة الخدمات',
		'add_new'            => 'إضافة خدمة',
		'edit_item'          => 'تحرير الخدمات',
		'new_item'           => 'خدمة جديد',
		'view_item'          => 'مشاهدة الخدمات',
		'search_items'       => 'البحث عن خدمة',
		'not_found'          => 'لا يوجد خدمات.',
		'not_found_in_trash' => 'لا يوجد خدمات',
		'parent_item_colon'  => 'القسم الرئيسى'
	),
	'supports'            => array( 'title', 'thumbnail', 'editor' )
) );


register_post_type( 'clients', array(
	'public'              => true,
	'hierarchical'        => false,
	'exclude_from_search' => false,
	'has_archive'         => false,
	'rewrite'             => array( 'slug' => 'clients' ),
	'capability_type'     => 'post',
	'taxonomies'          => array( 'post_tag' ),
	'labels'              => array(
		'name'               => 'العملاء',
		'add_new_item'       => 'إضافة عميل',
		'singular_name'      => 'العملاء',
		'menu_name'          => 'عملائنا',
		'name_admin_bar'     => 'عميل',
		'all_items'          => 'كافة العملاء',
		'add_new'            => 'إضافة عميل',
		'edit_item'          => 'تحرير العميل',
		'new_item'           => 'عميل جديد',
		'view_item'          => 'مشاهدة العملاء',
		'search_items'       => 'البحث عن عميل',
		'not_found'          => 'لا يوجد عملاء.',
		'not_found_in_trash' => 'لا يوجد عملاء',
		'parent_item_colon'  => 'القسم الرئيسى'
	),
	'supports'            => array( 'title', 'thumbnail', 'editor' )
) );

/*************************************************/
/* Tax */
/*************************************************/
add_action( 'init', 'create_services' );

function create_services() {
	register_taxonomy(
		'sec',
		'services',
		array(
			'label'             => __( 'أقسام الخدمات' ),
			'hierarchical'      => true,
			'show_ui'           => true,
			'show_admin_column' => true,
			'show_in_nav_menus' => true,
			'show_tagcloud'     => true,
			'public'            => true
		)
	);
}

/*************************************************/
/* Sizes */
/*************************************************/

add_image_size( 'slider-image', 1600, 614, true );

add_image_size( 'gallery-img-size', 250, 250, true );

add_image_size( 'small', 100, 100 );


/*************************************************/
/* Page Option */
/*************************************************/
if ( function_exists( 'acf_add_options_page' ) ) {

	acf_add_options_page( array(
		'page_title'    => 'اعدادات القالب',
		'menu_title'    => 'اعدادات القالب',
		'menu_slug'     => 'theme-general-settings',
		'capability'    => 'edit_posts',
		'update_button' => 'حفظ الاعدادات',
		'redirect'      => false
	) );

}


function mytheme_admin_bar_render() {
	global $wp_admin_bar;
	$wp_admin_bar->add_menu( array(
		'id'    => 'themeoptions',
		'title' => '<i class="options-icon"></i>' . __( 'اعدادات القالب', 'some-textdomain' ),
		'href'  => admin_url( 'admin.php?page=theme-general-settings' ),
		'icon'  => 'img'
	) );
}

// and we hook our function via
add_action( 'wp_before_admin_bar_render', 'mytheme_admin_bar_render' );


/*************************************************/
/* Sidebar */
/*************************************************/
if (function_exists('register_sidebar')) {
	register_sidebar(
		array(
			'name' => 'sidebar',
			'id' => 'sidebar',
			'description' => 'Sidebar',
			'before_widget' => '<div class="rest-of-news">',
			'after_widget' => '</div>',
			'before_title' => '<h1 class="box-section-title">',
			'after_title' => '</h1>'

		)
	);
}

// sticky post custom page
function wpb_cpt_sticky_at_top( $posts ) {

	// apply it on the archives only
	if ( is_main_query() && is_post_type_archive() ) {
		global $wp_query;

		$sticky_posts = get_option( 'sticky_posts' );
		$num_posts = count( $posts );
		$sticky_offset = 0;

		// Find the sticky posts
		for ($i = 0; $i < $num_posts; $i++) {

			// Put sticky posts at the top of the posts array
			if ( in_array( $posts[$i]->ID, $sticky_posts ) ) {
				$sticky_post = $posts[$i];

				// Remove sticky from current position
				array_splice( $posts, $i, 1 );

				// Move to front, after other stickies
				array_splice( $posts, $sticky_offset, 0, array($sticky_post) );
				$sticky_offset++;

				// Remove post from sticky posts array
				$offset = array_search($sticky_post->ID, $sticky_posts);
				unset( $sticky_posts[$offset] );
			}
		}

		// Look for more sticky posts if needed
		if ( !empty( $sticky_posts) ) {

			$stickies = get_posts( array(
				'post__in' => $sticky_posts,
				'post_type' => $wp_query->query_vars['post_type'],
				'post_status' => 'publish',
				'nopaging' => true
			) );

			foreach ( $stickies as $sticky_post ) {
				array_splice( $posts, $sticky_offset, 0, array( $sticky_post ) );
				$sticky_offset++;
			}
		}

	}

	return $posts;
}

add_filter( 'the_posts', 'wpb_cpt_sticky_at_top' );

// Add sticky class in article title to style sticky posts differently

function cpt_sticky_class($classes) {
	if ( is_sticky() ) :
		$classes[] = 'sticky';
		return $classes;
	endif;
	return $classes;
}
add_filter('post_class', 'cpt_sticky_class');